@@ -19,7 +19,7 @@
 int call_variants_from_plup(std::istream &cin, std::string out_file,
                             uint8_t min_qual, double min_threshold,
                             uint32_t min_depth, std::string ref_path,
-                            std::string gff_path);
+                            std::string gff_path, bool gapped_depth);
 std::vector<allele>::iterator get_ref_allele(std::vector<allele> &ad, char ref);
 
 #endif
